; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////

; Copyright (c) 2016 University of British Columbia, Joe Salkeld, Jessa Marley, Luke Crevier and Lael Parrott
;
; This material is the intellectual property of the University of British Columbia (UBC), Joe Salkeld, Jessa Marley,
; Luke Crevier and Lael Parrott. Any use, reproduction, incorporation, or derivative must: (1) reference the original authors
; (Joe Salkeld, Jessa Marley, Luke Crevier and Lael Parrott) and (2) include this copyright notice and information.
; UBC and the authors request that any party using this code or its derivatives contact us to inform us
; of its use. Luke Crevier can be contacted at lukepc@student.ubc.ca.

; Prior to use, the article describing this model should be read and referenced to understand assumptions,
; limitations, and other information regarding model use and input data.

; Recommended citation is:
; Crevier, L, Salkeld, J.H., Marley, J. and Parrott, L. 2021. Making the best possible choice: using agent-based modelling to
;  inform wildlife management in small communities. Ecological Modelling, in press.

; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////



;; --------------------------------   Variables
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////

;; --------------------------------   Load necessary extensions

extensions [
  profiler
  gis
  vid
  bitmap
  csv
]


;; --------------------------------   Declare global variables
globals [
  ; Constants
  HBI-Gradmax
  HBI-FCmax
  HBI-Habmax
  HBI-Detmax
  Prox-rating
  Move-options
  Buffer-distance
  max-steps
  current-date
  flee-count
  hbi_final
  fc_final
  sensors_ok?
  gis_loaded?
  human_patches
  taught_pop
  bin_pop
  road_abutting
  border_patches
  perim_patches
  perim_count

  ;;; Logging and output files
  long_step_list
  short_step_list
  long_angle_list
  short_angle_list
  init_start_time
  file-per_timestep
  file-per_bear
  file-per_scenario
  file-per_scenario_grad
  file-each-patch-use
  file-intersect-log
  recent_per_timestep
  recent_per_bear
  recent_per_scenario
  end_in_urban_count
  check_selected_value_list
  max_value_list


  ;;; GIS files

  gis_fences ;; serves as an importee for the fence lines
  current_fence_file

  ; rasters
  gis_BRY1 ;Berry season Rating Dec 1
  gis_BRY2 ;Berry season Rating Dec 2
  gis_BRY3 ;Berry season Rating Dec 3
  gis_PRB1 ;Pre-Berry Season Rating Dec 1
  gis_PRB2 ;Pre-Berry Season Rating Dec 2
  gis_PRB3 ;Pre-Berry Season Rating Dec 3
  gis_BHT1 ;Bear Habitat type Dec 1
  gis_BHT2 ;Bear Habitat type Dec 2
  gis_BHT3 ;Bear Habitat type Dec 3
  gis_DEC1 ;First Decile level in percent
  gis_DEC2 ;Second Decile level in percent
  gis_DEC3 ;Third Decile level in percent
  gis_SS1 ; Structural Stage of Dec 1
  gis_SS2 ; Structural Stage of Dec 2
  gis_SS3 ; Structural Stage of Dec 3
  gis_DTU ; Distance to urban in 100m bands
  gis_HRB ; Highest rating in berry season
  gis_HRP ; Highest rating in pre-berry season
  gis_BLD ; building indicator
  gis_URB
  gis_zone



  ;Initalization variables
  season

  ;Working Counters

  index1 ;index counter used for the summation loop (used in go-move)
  index2 ; index counter used for the position in original list of the desired foodmem (used in go-move)

  ;Working variables
  outside? ; boolian for if the bear is in the buffer or not.
  time-outside ; Amount of time the bear spends in the buffer region
  last-position ; position the bear returns to after the time spent in the buffer region
  dist ; Distances possible to select from in a given time-step (used in go-move)
  angle ; Angles possible to select from in a given time-step (used in go-move)
  int-step-len ; Holds intermediate step length for bears

  ;Working Lists
  move-list ;list of all possible distances and angles (used in go-move)
  cumsum-list ; list of cumulative food and memory (used in go-move)

  ;End Lists per timestep
  MoveLength-list
  TurnAngles-list
  Pxcords-list
  Pycords-list
  track_output_list

  ;Bin-list ; Number of times a bear encounters a tyedee bin

  ;End Counters per bear
  survival_bears ;counter for Survival bears
  conflict_bears ; counter for Conflict bears
  aversive_bears ; counter for AC-bears
  HBI+ ; Human bear interaction with positive human
  HBI- ; Human bear interaction negative humantcome
  aveMoveLength ; Average movement length (used in move-calcs)
  Moves ;total number of moves
  Totaldistance ; Total distance traveled by the bear (used in move-calcs)
  totaltime-outside
]

;; --------------------------------   Declare patch-specfic variables

patches-own [
  ;Initially read in variables from GIS txt files
  BRY1 ;Berry season Rating Dec 1
  BRY2 ;Berry season Rating Dec 2
  BRY3 ;Berry season Rating Dec 3
  PRB1 ;Pre-Berry Season Rating Dec 1
  PRB2 ;Pre-Berry Season Rating Dec 2
  PRB3 ;Pre-Berry Season Rating Dec 3
  BHT1 ;Bear Habitat type Dec 1
  BHT2 ;Bear Habitat type Dec 2
  BHT3 ;Bear Habitat type Dec 3
  DEC1 ;First Decile level in percent
  DEC2 ;Second Decile level in percent
  DEC3 ;Third Decile level in percent
  SS1 ; Structural Stage of Dec 1
  SS2 ; Structural Stage of Dec 2
  SS3 ; Structural Stage of Dec 3
  DTU ; Distance to urban in 100m bands
  HRB ; Highest rating in berry season
  HRP ; Highest rating in pre-berry season
  BLD ; building indicator
  Urb ; Urban food
  Zone; Zoning information, see other file for translation
  Buffer? ; boolian for if the patch is in the buffer
  recent_use
  used_this_pathfind?
  usage_count
  bear_seen_count

  ;variables used for each run
  food ; generic food term used as importing space saver.
  food-hum  ; food value from a human occupied patch 1 (low) to 5 (high)
  food-nat  ; food value from a covered patch 1 (low) to 5 (high)
  food-buf  ; food value in the buffer region
  human ; value of human occupant, +1 (attractive), 0 (neutral), and -1 (repellant)
  educated ; value to show if human has been bear educated.
  det_prob ;Probabillity that a bear is dettered at a given urban location
  std_det_prob ; The starting deterrence probability of a cell (after teaching)
  memory ; the bears increased (found good food) or decreased (repelled by human) attachment to an area
  bin ;value to show if human has a tyedee bin
]

;; --------------------------------   Declare bear-specific variabls

bears-own [
  current_target
  dist-to-target
  fleeing?
  int_step_len
  dtx
  dty
  HBI ;the running counter for how many positive - negative HBI's the bear has had. (x-axis)
  deterred ; number of times the bear has been spooked by a human, starts at 0
  det-rad ; the decreasing deterant radius of the bear
  death ; tracks the number of times the bear has died.
  free  ; tracks the number of tick-list a bear is set free
  MoveLength ; Distance selected to move by the bear in a given time-step (used in data-movecalcs)
  TurnAngle ;Turn angle selected to move by the bear in a given time-step (used in data-movecalcs
  food-nat-consumed
  FC ; used for how food conditioned the bear is (Y-axis)
]

;; --------------------------------   Define the breeds used

breed [ bears bear ]
breed [ houses house ]
breed [ arrows arrow ]
breed [ setters setter ]
breed [ senses sense ]
breed [ vertices vertex ]

; ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;; --------------------------------   Loading procedures
to A-1-loading-procedures end
  ; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  ;; --------------------------------   Clear all variables and set up the initials constants

to startup
  ca ; clears all from last run
  setup-date   ;;; notes the current date/time
  Simulate-Set_Constants
  print ("Reset-ticks. Going to load landscape...")
  gis-load-landscape
  print ("Loaded landscape from GIS files.")
  setup-create-human
  print (word "created human. Going to setup scenario " teaching-layout bin-layout teaching-fraction bin-fraction)
  print ("setup scenario complete. Going to create food...")
  setup-create-food
  print ("created food. Going to create buffer...")
  setup-buffer
  print ("created buffer. Going to setup scenario...")
  set gis_fences nobody
  setup-scenario-2
  set-default-shape vertices "circle"
  let recent_startup (word "Results/" current-date "_startup.txt")
  print ("Startup complete.")
  reset-ticks
end

;; --------------------------------   Get the current date from the system and save it as a human-readable string

to setup-date
  set current-date ( word (substring date-and-time 0 2) (substring date-and-time 3 5) (substring date-and-time 13 15) "_" ( substring date-and-time 16 27 ) )
  print( word "Current setup started: " current-date)
end

;; -------------------------------- Load landscape GIS files and apply values to patches

to gis-load-landscape
  ; user-message "loading RMOW GIS landscape from GIS files?"
  let init date-and-time

  ;;;; Load the proper extents from a text file- (extent of netlogo image once translated to 25sqm raster UTM 10N)
  let base_env gis:envelope-of gis:load-dataset "GIS_files/raster_layers/bht1.asc"
  let x_range abs(item 0 base_env - item 1 base_env)
  let y_range abs(item 2 base_env - item 3 base_env)

  let x_mod x_range * 0.025
  let y_mod y_range * 0.025
  let mod_vals_list ( list (-1 * x_mod) x_mod (-1 * y_mod) y_mod)
  let new_env ( map [ [ val modi ] -> val + modi ] base_env mod_vals_list )
  gis:set-world-envelope new_env
  file-close

  ;/////////////////////////////////////// BHT1 ////////////////////////////////////////////////////////////////

  ;;; Assign the raster files to the appropriate file name
  set gis_bht1 gis:load-dataset "GIS_files/raster_layers/bht1.asc"
  set gis_bht2 gis:load-dataset "GIS_files/raster_layers/bht2.asc"
  set gis_bht3 gis:load-dataset "GIS_files/raster_layers/bht3.asc"
  set gis_bld gis:load-dataset "GIS_files/raster_layers/bld.asc"
  set gis_bry1 gis:load-dataset "GIS_files/raster_layers/bry1.asc"
  set gis_bry2 gis:load-dataset "GIS_files/raster_layers/bry2.asc"
  set gis_bry3 gis:load-dataset "GIS_files/raster_layers/bry3.asc"
  set gis_dec1 gis:load-dataset "GIS_files/raster_layers/dec1.asc"
  set gis_dec2 gis:load-dataset "GIS_files/raster_layers/dec2.asc"
  set gis_dec3 gis:load-dataset "GIS_files/raster_layers/dec3.asc"
  set gis_dtu gis:load-dataset "GIS_files/raster_layers/dtu.asc"
  set gis_hrb gis:load-dataset "GIS_files/raster_layers/hrb.asc"
  set gis_hrp gis:load-dataset "GIS_files/raster_layers/hrp.asc"
  set gis_prb1 gis:load-dataset "GIS_files/raster_layers/prb1.asc"
  set gis_prb2 gis:load-dataset "GIS_files/raster_layers/prb2.asc"
  set gis_prb3 gis:load-dataset "GIS_files/raster_layers/prb3.asc"
  set gis_ss1 gis:load-dataset "GIS_files/raster_layers/ss1.asc"
  set gis_ss2 gis:load-dataset "GIS_files/raster_layers/ss2.asc"
  set gis_ss3 gis:load-dataset "GIS_files/raster_layers/ss3.asc"
  set gis_urb gis:load-dataset "GIS_files/raster_layers/urb.asc"
  set gis_zone gis:load-dataset "GIS_files/raster_layers/zone.asc"


  print ("loaded the rasters")

  ;;; Apply the raster dataset values to the patchesgis:apply-raster gis_bht1 bht1
  gis:apply-raster gis_bht1 bht1
  gis:apply-raster gis_bht2 bht2
  gis:apply-raster gis_bht3 bht3
  gis:apply-raster gis_bld bld
  gis:apply-raster gis_bry1 bry1
  gis:apply-raster gis_bry2 bry2
  gis:apply-raster gis_bry3 bry3
  gis:apply-raster gis_dec1 dec1
  gis:apply-raster gis_dec2 dec2
  gis:apply-raster gis_dec3 dec3
  gis:apply-raster gis_dtu dtu
  gis:apply-raster gis_hrb hrb
  gis:apply-raster gis_hrp hrp
  gis:apply-raster gis_prb1 prb1
  gis:apply-raster gis_prb2 prb2
  gis:apply-raster gis_prb3 prb3
  gis:apply-raster gis_ss1 ss1
  gis:apply-raster gis_ss2 ss2
  gis:apply-raster gis_ss3 ss3
  gis:apply-raster gis_urb urb
  gis:apply-raster gis_zone zone

  print ("applied rasters")

  ask patches with [dec1 < 0 or dec1 > 0 ] [
    set dec1 dec1 / 10
    set dec2 dec2 / 10
    set dec3 dec3 / 10
  ]

  set gis_loaded? true
end

;; -------------------------------- Load interface-selected fence shapefile

to gis-load-fences

  ;;;; Check if there is currently a fence file loaded, if there is unload it.
  if gis_fences != nobody [
    set gis_fences gis:load-dataset current_fence_file
    gis-unload-fences
  ]

  ;;;; Load the actual fence features
  let fence_choice nobody

  set fence_choice (word "GIS_files/new_fences/" fence-config)
  ;  if fence-config = "extensive" [
  ;    set fence_choice "GIS_files/new_fences/new_urban_utm.shp"
  ;  ]
  ;  if fence-config = "convex" [
  ;    set fence_choice "GIS_files/new_fences/urban_convex.shp"
  ;  ]
  ;  if fence-config = "drift" [
  ;    set fence_choice "GIS_files/new_fences/drift.shp"
  ;  ]

  if fence-config != "No fence" [
    set gis_fences gis:load-dataset fence_choice
    set current_fence_file fence_choice
    gis:set-drawing-color yellow
    gis:draw gis_fences 1
  ]

end


;; -------------------------------- Unload the loaded fence file

to gis-unload-fences
  ;;;; erase fence lines and remove the fence dataset
  ifelse gis_fences != nobody [
    ask patches gis:intersecting gis_fences [
      sprout 1 [
        set shape "square"
        set heading 0
        set size 3
        stamp-erase
        die
      ]
    ]
    set gis_fences nobody
  ]
  [
    print "No fence shapefile is currently loaded."
  ]

end

;; -------------------------------- Reset all values to a base setting

to set-variable-base-values

  set auto-reinitialize? false
  set HighestValue false
  set HBI-factor 12
  set FC-Factor 12
  set Teaching-Type "IncDet"
  set Teaching-Layout "Random"
  set Bin-Layout "Random"
  set teaching-fraction 0
  set bin-fraction 0
  set Urban-Food "Zones"
  set teach-bin-rela "Random"
  set implement-first "Bins"
  set fence-config "no_fence.shp"
  set fences-on? false
  set conservation-officer? false
  set spawning-type "random"
  set base_det_prob 0.0315
  set teach_factor 10
  set travel_factor 100
  set conservation_factor 2
  set vegetation-modification "None"
end

;; -------------------------------- Designate all cells with a BHT1 value of '7' as human

to setup-create-human
  ask patches[
    if BHT1 = 7 [
      set human 1
      if Urban-food = "Random"[
        set food-hum ( random 6 ) + 1
      ]
      if Urban-food = "Zones"[
        set food-hum urb
      ]
      set DTU 0
      set det_prob base_det_prob
    ]
    if bld = 1 [
      set human 1
      if Urban-food = "Random"[
        set food-hum (random 2 ) + 4
      ]
      if Urban-food = "Zones"[
        set food-hum urb
      ]
      set DTU 0
      set det_prob 0.0315
    ]
  ]
end


;; -------------------------------- Calculate food values for the pre-berry and post-berry landscape

to setup-create-food
  ask patches with [ BHT1 >= 0 ][
    if season = 0 [ ; Pre-berry
      ifelse highestvalue = true
      [ set food-nat (6 - HRP ) ] ;Highest seasonal rating
      [ if PRB1 > 0 and PRB2 > 0 and PRB3 > 0 [set food-nat (  ( DEC1 *(6 - PRB1) )  +  ( DEC2 *(6 - PRB2) ) +  ( DEC3 *(6 - PRB3)) )]
        if PRB1 > 0 and PRB2 > 0 and PRB3 <= 0 [set food-nat (DEC1 *(6 - PRB1) + DEC2 *(6 - PRB2))/ (DEC1 + DEC2) ]
        if PRB1 > 0 and PRB2 <= 0 and PRB3 <= 0 [set food-nat (DEC1 *(6 - PRB1)/ DEC1) ]
      ]

    ]
    if season = 1[ ;Berry
      ifelse highestvalue = true
      [ set food-nat (6 - HRB ) ] ;Highest seasonal rating
      [ if BRY1 > 0 and BRY2 > 0 and BRY3 > 0 [set food-nat (DEC1 *(6 - BRY1) + DEC2 *(6 - BRY2) + DEC3 *(6 - BRY3))]
        if BRY1 > 0 and BRY2 > 0 and BRY3 <= 0 [set food-nat (DEC1 *(6 - BRY1) + DEC2 *(6 - BRY2)) / (DEC1 + DEC2)]
        if BRY1 > 0 and BRY2 <= 0 and BRY3 <= 0 [set food-nat (DEC1 *(6 - BRY1)/ DEC1) ]]
    ]
  ]

  if any? patches with [ food-nat > 5 ] [
    ask patches with [food-nat > 5 ] [
      set food-nat max [food-nat] of neighbors with [ buffer? != TRUE ]
    ]
  ]

  setup-veg-mods
end

;; -------------------------------- Choose the vegetation modification (if any)

to setup-veg-mods
  if vegetation-modification = "100m buffer reduction" [
    gis-modify-100m-buffer
  ]

  if vegetation-modification = "200m buffer reduction" [
    gis-modify-200m-buffer
  ]

  if vegetation-modification = "3 diversionary points" [
    gis-diversionary-feeding-points
  ]

  if vegetation-modification = "400m-600m buffer increase" [
    gis-diversionary-feeding-band
  ]

  if vegetation-modification = "Poor berry crop" and season = 1 [
    set-veg-inferior-berry
    print "Setup low berry yield."
  ]

  if vegetation-modification = "Superior berry crop" and season = 1 [
    set-veg-superior-berry
    print "Setup high berry yield."
  ]

end

;; -------------------------------- Create a buffer in unmapped cells based on the buffer distance

to setup-buffer
  ask patches with [ not ( BHT1 > 0 or BHT1 < 0 ) ] [
    set BHT1 -9999
  ]

  ask patches with [BHT1 < 0] [
    if any? patches in-radius ( buffer-distance / 25 ) with [ BHT1 > 0 ] [
      set buffer? true
    ]
  ]
  buffer-food
end

;; -------------------------------- Create food values for the buffer areas

to buffer-food
  ;Hot Fixes
  ask patch 0 121 [ set food-buf 1 ]
  ask patch 551 31 [ set food-buf 1 ]
  ask patches with [ food-nat > 6 or food-nat < -1][
    set food-nat sum [ food-nat] of neighbors / count neighbors with [ food-buf > 0 or food-nat > 0]]

  ;Buffer-food
  while [ any? patches with [ buffer? = true and food-buf <= 0 ]] [
    ask patches with [ buffer? = true ][
      if any? neighbors with [food-buf > 0 or food-nat > 0][
        set food-buf sum [food-buf + food-nat] of neighbors / count neighbors with [ food-buf > 0 or food-nat > 0]
        set pcolor orange
      ]
    ]
  ]
end

;; -------------------------------- Reduce natural food values within 100m of urban area

to gis-modify-100m-buffer
  let buffer_zone gis:load-dataset "GIS_files/modify_nat_food/reduced_food_100m.shp"

  let buffered_patches patches gis:intersecting buffer_zone

  ask buffered_patches with [ bht1 != 7 and food-nat >= 1 ] [
    set food-nat 1
  ]
end

;; -------------------------------- Reduce natural food values within 200m of urban area

to gis-modify-200m-buffer
  let buffer_zone gis:load-dataset "GIS_files/modify_nat_food/reduced_food_200m.shp"

  let buffered_patches patches gis:intersecting buffer_zone

  ask buffered_patches with [ bht1 != 7 and food-nat >= 1 ] [
    set food-nat 1
  ]
end

;; -------------------------------- Increase natural food values at three point areas away from the urban area

to gis-diversionary-feeding-points
  let diversionary_zones gis:load-dataset "GIS_files/modify_nat_food/div_feed_areas.shp"

  let buffered_patches patches gis:intersecting diversionary_zones

  ask buffered_patches with [ bht1 != 7 and food-nat >= 1 ] [
    set food-nat 7
  ]
end

;; -------------------------------- Increase natural food values in a 200m thick band starting 400m from urban areas

to gis-diversionary-feeding-band
  let diversionary_zones gis:load-dataset "GIS_files/modify_nat_food/diversionary_band.shp"

  let buffered_patches patches gis:intersecting diversionary_zones

  ask buffered_patches with [ bht1 != 7 and food-nat >= 1 ] [
    set food-nat 7
  ]
end

;; -------------------------------- Decrease natural food in a poor berry crop year

to set-veg-inferior-berry
  ask patches with [ food-nat > 1 ] [
    set food-nat food-nat - 1
  ]
end


;; -------------------------------- Increase natural food in a superior berry crop year

to set-veg-superior-berry
  ask patches with [ food-nat >= 4 and food-nat < 5 ] [
    set food-nat 5
  ]
  ask patches with [ food-nat > 0 and food-nat < 4 ] [
    set food-nat food-nat + 1
  ]
end



; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;; --------------------------------   Setup and configurations of different teaching / bin configurations

to setup-scenario-2
  ask patches with [ BHT1  = 7 ] [
    set human 1
  ]

  ask patches with [ human = 1 ] [
    set bin 0
    set educated 0
  ]

  set taught_pop floor ( (count patches with [ human = 1 ]) * teaching-fraction )
  set bin_pop floor ((count patches with [ human = 1 ]) * bin-fraction )
  set human_patches ( patches with [ human = 1 ] )

  if teach-bin-rela = "Random" [       ;\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ Random Teach/Bin layout relationship

    ;;; ----------------- Treats teaching and binning as independent

    if Teaching-Layout = "Random" [                       ;;; Random teaching configuration
      setup-taught-random
    ]

    if Teaching-Layout = "Cluster" [                      ;;; Clustered teaching configuration
      setup-taught-cluster
    ]

    if Teaching-Layout = "Perimeter Inclusive" [          ;;; Perimeter of "human" areas, excluding roads as human zone
      setup-taught-perimeter-inclusive
    ]

    if Teaching-Layout = "Perimeter Conservative" [       ;;; Perimeter of "human" areas, treating roads as human zone/barrier
      setup-taught-perimeter-conservative
    ]

    if bin-layout = "Random" [                            ;;; Random bin teaching configuration
      setup-bin-random
    ]

    if bin-layout = "Cluster" [                           ;;; Clustered bin configuration
      setup-bin-cluster
    ]

    if bin-layout = "Perimeter Inclusive" [               ;;; Perimeter of "human" areas, excluding roads as human zone
      setup-bin-perimeter-inclusive
    ]

    if bin-layout = "Perimeter Conservative" [            ;;;  Perimeter of "human" areas, treating roads as human zone/barrier
      setup-bin-perimeter-conservative
    ]
  ]

  ;   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /

  if teach-bin-rela = "Overlap" [       ;\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ Teaching and binning overlap configurations
    if implement-first = "Teaching" [

      ;;---------------------------------- Implement teaching first, then bin only the bin-fraction of taught patches
      setup-overlap-taught-first
    ]

    if implement-first = "Bins" [
      ;;---------------------------------- Implement binning first, then teach only the bin-fraction of taught patches

      setup-overlap-bin-first
    ]
  ]

  ;   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /


  if teach-bin-rela = "Opposite" [       ;\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ This treats any taught cells cells that CANNOT be bin cells

    if implement-first = "Teaching" [
      ;;---------------------------------- Implement teaching first, then bin only the bin-fraction of untaught patches

      setup-opposite-taught-first

    ]

    if implement-first = "Bins" [
      ;;---------------------------------- Implement bins first, then teach only the bin-fraction of unbinned patches

      setup-opposite-bin-first

    ]

  ]


  ;   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /   /


  ;;;------------------------------------------------------------------------------ Once whatever teaching configuration has been implemented, identify the taught patches
  ask patches with [ educated = 1 ] [
    set pcolor blue
  ]
  ask patches with [ bin = 1 ] [
    set pcolor yellow
  ]

  ask patches with [ bin = 1 and educated = 1 ] [
    set pcolor violet
  ]

  print( "Assigned colors to taught/bin/both patches.")

  ;;; ---------------------------------------------------------------------------- If any "BHT1 = 7" cells were temporarily set to "Human = 0", reestablish humanity
  ask patches with [ BHT1  = 7 ] [
    set human 1
  ]
  print( "Reset humanity.")

  if Teaching-Type = "none" and count patches with [ educated = 1] >= 0[
    set Teaching-Type user-one-of "Please select a teaching type" ["IncDet" "DecFood-Urb" "Both" ]
  ]
  if Teaching-Type = "IncDet" [
    ask patches with [educated = 1 ] [
      set det_prob base_det_prob * teach_factor
    ]
  ]
  if Teaching-Type = "DecFood-Urb" [
    ask patches with [educated = 1 ] [
      set food-hum 1
      set memory 1
    ]
  ]
  if Teaching-Type = "Both" [
    ask patches with [educated = 1 ] [
      set det_prob base_det_prob * teach_factor
      set food-hum 1
      set memory 1
    ]
  ]

  ask patches [
    set std_det_prob det_prob
  ]
  print ("Finished scenario setup.")

end


to setup-overlap-bin-first
  if bin-layout = "Random" [                            ;;; Random bin teaching configuration
    setup-bin-random
  ]

  if bin-layout = "Cluster" [                           ;;; Clustered bin configuration
    setup-bin-cluster
  ]

  if bin-layout = "Perimeter Inclusive" [               ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-bin-perimeter-inclusive
  ]

  if bin-layout = "Perimeter Conservative" [            ;;;  Perimeter of "human" areas, treating roads as human zone/barrier
    setup-bin-perimeter-conservative
  ]

  ;;; Temporarily set non-bin patches to "Human = 0" for teaching purposes
  ask patches with [ human = 1 and bin = 0 ] [
    set human 0
  ]
  set taught_pop floor (( count patches with [ human = 1 and bin = 1 ] ) * teaching-fraction )

  if Teaching-Layout = "Random" [                       ;;; Random teaching configuration
    setup-taught-random
  ]

  if Teaching-Layout = "Cluster" [                      ;;; Clustered teaching configuration
    setup-taught-cluster
  ]

  if Teaching-Layout = "Perimeter Inclusive" [          ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-taught-perimeter-inclusive
  ]

  if Teaching-Layout = "Perimeter Conservative" [       ;;; Perimeter of "human" areas, treating roads as human zone/barrier
    setup-taught-perimeter-conservative
  ]
end


to setup-overlap-taught-first
  if Teaching-Layout = "Random" [                       ;;; Random teaching configuration
    setup-taught-random
  ]

  if Teaching-Layout = "Cluster" [                      ;;; Clustered teaching configuration
    setup-taught-cluster
  ]

  if Teaching-Layout = "Perimeter Inclusive" [          ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-taught-perimeter-inclusive
  ]

  if Teaching-Layout = "Perimeter Conservative" [       ;;; Perimeter of "human" areas, treating roads as human zone/barrier
    setup-taught-perimeter-conservative
  ]

  ;;; Temporarily set non-taught patches to "Human = 0" for binning purposes
  ask patches with [ human = 1 and educated = 0 ] [
    set human 0
  ]
  set bin_pop floor (( count patches with [ human = 1 and educated = 1 ] ) * bin-fraction )

  if bin-layout = "Random" [                            ;;; Random bin teaching configuration
    setup-bin-random
  ]

  if bin-layout = "Cluster" [                           ;;; Clustered bin configuration
    setup-bin-cluster
  ]

  if bin-layout = "Perimeter Inclusive" [               ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-bin-perimeter-inclusive
  ]

  if bin-layout = "Perimeter Conservative" [            ;;;  Perimeter of "human" areas, treating roads as human zone/barrier
    setup-bin-perimeter-conservative
  ]

end


to setup-opposite-bin-first
  if bin-layout = "Random" [                            ;;; Random bin teaching configuration
    setup-bin-random
  ]

  if bin-layout = "Cluster" [                           ;;; Clustered bin configuration
    setup-bin-cluster
  ]

  if bin-layout = "Perimeter Inclusive" [               ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-bin-perimeter-inclusive
  ]

  if bin-layout = "Perimeter Conservative" [            ;;;  Perimeter of "human" areas, treating roads as human zone/barrier
    setup-bin-perimeter-conservative
  ]

  ;;; Temporarily set non-bin patches to "Human = 0" for teaching purposes
  ask patches with [ bin = 1 ] [
    set human 0
  ]
  set taught_pop floor (( count patches with [ human = 1 ] ) * teaching-fraction )

  if Teaching-Layout = "Random" [                       ;;; Random teaching configuration
    setup-taught-random
  ]

  if Teaching-Layout = "Cluster" [                      ;;; Clustered teaching configuration
    setup-taught-cluster
  ]

  if Teaching-Layout = "Perimeter Inclusive" [          ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-taught-perimeter-inclusive
  ]

  if Teaching-Layout = "Perimeter Conservative" [       ;;; Perimeter of "human" areas, treating roads as human zone/barrier
    setup-taught-perimeter-conservative
  ]
end


to setup-opposite-taught-first
  print ("setting up opposite taught first")

  if Teaching-Layout = "Random" [                       ;;; Random teaching configuration
    setup-taught-random
  ]

  if Teaching-Layout = "Cluster" [                      ;;; Clustered teaching configuration
    setup-taught-cluster
  ]

  if Teaching-Layout = "Perimeter Inclusive" [          ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-taught-perimeter-inclusive
  ]

  if Teaching-Layout = "Perimeter Conservative" [       ;;; Perimeter of "human" areas, treating roads as human zone/barrier
    setup-taught-perimeter-conservative
  ]

  ;;; Temporarily set non-taught patches to "Human = 0" for binning purposes
  ask patches with [ educated = 1 ] [
    set human 0
  ]
  set bin_pop floor (( count patches with [ human = 1 ] ) * bin-fraction )

  if bin-layout = "Random" [                            ;;; Random bin teaching configuration
    setup-bin-random
  ]

  if bin-layout = "Cluster" [                           ;;; Clustered bin configuration
    setup-bin-cluster
  ]

  if bin-layout = "Perimeter Inclusive" [               ;;; Perimeter of "human" areas, excluding roads as human zone
    setup-bin-perimeter-inclusive
  ]

  if bin-layout = "Perimeter Conservative" [            ;;;  Perimeter of "human" areas, treating roads as human zone/barrier
    setup-bin-perimeter-conservative
  ]
end

to setup-taught-random

  ;;;---------------------------------------- Procedure to teach random human patches
  ask n-of taught_pop patches with [ human = 1 ] [
    set educated 1
  ]

end

to setup-taught-cluster

  ;;;---------------------------------------- Procedure to cluster teaching around buildings
  ifelse taught_pop > (count patches with [ bld = 1 ] ) [
    ask patches with [ bld = 1 ] [
      set educated 1
      set pcolor blue
    ]

    let prev_educated ""
    while [ count patches with [ educated = 1 ] < taught_pop ] [
      let count_edded count patches with [educated = 1 ]
      let count_to_ed taught_pop - count_edded
      let half_to_ed floor (count_to_ed / 2)
      let cluster_edges patches with [ educated = 1 and any? neighbors with [ educated = 0 and human = 1 ] ]
      let count_cluster_edges count cluster_edges

      if prev_educated = half_to_ed [
        ask one-of patches with [ human = 1 and educated = 0 ] [
          set educated 1
          set pcolor blue
        ]
      ]

      if print-to-console? [
        print (word  "total to educate: " count_to_ed )
        print (word "previously educated " prev_educated)
        print (word "Educating " half_to_ed " this round." )
      ]


      ifelse half_to_ed < count_cluster_edges [
        let edges_growing n-of half_to_ed cluster_edges
        if edges_growing != nobody [
          ask n-of half_to_ed cluster_edges [
            let potential_neighbor one-of neighbors with [ educated = 0 and human = 1 ]
            if potential_neighbor != nobody [
              ask one-of neighbors with [ educated = 0 and human = 1 ] [
                set educated 1
                set pcolor blue
              ]
            ]
          ]
        ]
      ]
      [
        ask cluster_edges [
          let potential_neighbor one-of neighbors with [ educated = 0 and human = 1 ]
          if potential_neighbor != nobody [
            ask potential_neighbor [
              set educated 1
              set pcolor blue
            ]
          ]
        ]
      ]
      set prev_educated half_to_ed
    ]
  ]

  [
    ask n-of taught_pop patches with [ bld = 1 ] [
      set educated 1
    ]

  ]

end


to setup-taught-perimeter-inclusive
  set perim_patches patches with [ human = 1 and any? neighbors with [ human = 0 ] ]
  set perim_count count perim_patches
  setup-taught-perimeter
  if print-to-console? [
    print (word "Taught " count patches with [ educated = 1 ]  " patches out of " taught_pop " target patches." )
  ]
end


to setup-taught-perimeter-conservative
  ;;; Sets the agent-set of patches that are next to wildlands, but not next to a road
  set road_abutting patches with [ human = 1 and any? neighbors with [ human = 0 and bht1 != 5 ] and any? neighbors with [ bht1 = 5 ] ]
  set border_patches patches with [ human = 1 and any? neighbors with [ human = 0 ] and not any? neighbors with [ bht1 = 5 ] ]
  set perim_patches (patch-set road_abutting border_patches )
  set perim_count count perim_patches
  setup-taught-perimeter
  if print-to-console? [
    print (word "Taught " count patches with [ educated = 1 ]  " patches out of " taught_pop " target patches." )
  ]
end


to setup-taught-perimeter

  ;;;---------------------------------------- Procedure to educate patches in the perimeter
  ;;;; Check if the patches to-be-taught are more numerous than the perimeter patches
  ifelse taught_pop > perim_count [ ;;;-------------- If they ARE more numerous
    ask perim_patches [
      set educated 1
      set pcolor blue
    ]

    while [ ( count patches with [educated = 1 ] ) < taught_pop ] [
      let educ_patches patches with [ educated = 1 ]
      let educ_count count educ_patches
      let educatable_patches educ_patches with [ any? neighbors with [ human = 1 and educated = 0 ] ]
      let count_educatable count educatable_patches
      let n_to_educate taught_pop - educ_count
      if n_to_educate > count_educatable [
        set n_to_educate count_educatable
      ]

      ask n-of n_to_educate educatable_patches [
        let to_educate one-of neighbors with [ educated = 0 and human = 1 ]
        if to_educate != nobody [
          ask to_educate [
            set pcolor blue
            set educated 1
          ]
        ]
      ]
    ]
  ]
  [ ;;; -------------------------------------------- If they are NOT more numerous
    ask n-of ( taught_pop / 3 ) perim_patches [
      set educated 1
      set pcolor blue
    ]

    let edded count perim_patches with [educated = 1 ]
    let n_to_ed taught_pop - edded
    while [ n_to_ed > 0 ] [
      set edded count perim_patches with [educated = 1 ]
      set n_to_ed taught_pop - edded
      let educatable_perim perim_patches with [ educated = 1 and any? neighbors with [ human = 1 and educated = 0 ] ]
      let educatable_count count educatable_perim
      let sub_n_to_ed n_to_ed / 2
      if print-to-console? [
        print ( word "Must teach " n_to_ed " patches ")
      ]

      if n_to_ed < 50 [
        set sub_n_to_ed 10
        if n_to_ed < 10 [
          set sub_n_to_ed 1
        ]
      ]
      if sub_n_to_ed > educatable_count [
        set sub_n_to_ed educatable_count
      ]
      if educatable_count = 0 [
        set n_to_ed 0
      ]

      if print-to-console? [
        print ( word "there are " educatable_count " patches available for education ")
        print ( word "trying to educate " sub_n_to_ed " patches")
      ]

      ask n-of sub_n_to_ed educatable_perim [
        let perim_neighbors neighbors with [ member? self perim_patches ]
        let target one-of perim_neighbors with [ human = 1 ]
        if target != nobody [
          ask target [
            set educated 1
            set pcolor blue
          ]
        ]
      ]
    ]
  ]
end


to setup-bin-random

  ;;;---------------------------------------- Procedure to put bins on random human patches
  ask n-of bin_pop patches with [ human = 1 ] [
    set bin 1
    set pcolor yellow
  ]
end


to setup-bin-cluster

  ;;;---------------------------------------- Procedure to cluster bins around buildings
  ifelse bin_pop > (count patches with [ bld = 1  and human = 1] ) [
    ask patches with [ bld = 1 and human = 1 ] [
      set bin 1
      set pcolor yellow
    ]

    let prev_bin ""
    while [ count patches with [ bin = 1 ] < bin_pop ] [
      let count_binned count patches with [bin = 1 ]
      let count_to_bin bin_pop - count_binned
      let half_to_bin floor (count_to_bin / 2)
      let cluster_edges patches with [ bin = 1 and any? neighbors with [ bin = 0 and human = 1 ] ]
      let count_cluster_edges count cluster_edges

      if prev_bin = half_to_bin [
        ask one-of patches with [ human = 1 and bin = 0 ] [
          set bin 1
          set pcolor yellow
        ]
      ]

      if print-to-console? [
        print (word  "total to bin: " count_to_bin )
        print (word "previously bin " prev_bin)
        print (word "Binning " half_to_bin " this round." )
      ]


      ifelse half_to_bin < count_cluster_edges [
        let edges_growing n-of half_to_bin cluster_edges
        if edges_growing != nobody [
          ask n-of half_to_bin cluster_edges [
            let potential_neighbor one-of neighbors with [ bin = 0 and human = 1 ]
            if potential_neighbor != nobody [
              ask potential_neighbor [
                set bin 1
                set pcolor yellow
              ]
            ]
          ]
        ]
      ]
      [
        ask cluster_edges [
          let potential_neighbor one-of neighbors with [ bin = 0 and human = 1 ]
          if potential_neighbor != nobody [
            ask potential_neighbor [
              set bin 1
              set pcolor yellow
            ]
          ]
        ]
      ]
      set prev_bin half_to_bin
    ]
  ]

  [
    ask n-of bin_pop patches with [ bld = 1 ] [
      set bin 1
    ]
  ]

end


to setup-bin-perimeter-inclusive
  set perim_patches patches with [ human = 1 and any? neighbors with [ human = 0 ] ]
  set perim_count count perim_patches
  setup-bin-perimeter
  if print-to-console? [
    print (word "Binned " count patches with [ bin = 1 ] " out of " bin_pop " target patches. " )
  ]
end


to setup-bin-perimeter-conservative
  ;;; Sets the agent-set of patches that are next to wildlands, but not next to a road
  set road_abutting patches with [ human = 1 and any? neighbors with [ human = 0 and bht1 != 5 ] and any? neighbors with [ bht1 = 5 ] ]
  set border_patches patches with [ human = 1 and any? neighbors with [ human = 0 ] and not any? neighbors with [ bht1 = 5 ] ]
  set perim_patches (patch-set road_abutting border_patches )
  set perim_count count perim_patches

  setup-bin-perimeter
  if print-to-console? [
    print (word "Binned " count patches with [ bin = 1 ] " out of " bin_pop " target patches. " )
  ]
end


to setup-bin-perimeter

  ;;;---------------------------------------- Procedure to bin patches in the perimeter
  ;;;; Check if the patches to-be-binned are more numerous than the perimeter patches
  ifelse bin_pop > perim_count [ ;;;-------------- If they ARE more numerous
    if print-to-console? [
      print ("They are more numerous")
    ]
    ask perim_patches [
      set bin 1
      set pcolor yellow
    ]
    while [ ( count patches with [bin = 1 ] ) < bin_pop ] [
      let binned_patches patches with [ bin = 1 ]
      let binnable_patches binned_patches with [ any? neighbors with [ human = 1 and bin = 0 ] ]
      let binned_count count binned_patches
      let binnable_count count binnable_patches
      let n_to_bin bin_pop - binned_count
      if n_to_bin > binnable_count [
        set n_to_bin binnable_count
      ]

      ask n-of n_to_bin binnable_patches [
        let to_bin one-of neighbors4 with [ bin = 0 and human = 1 ]
        if to_bin != nobody [
          ask to_bin [
            set pcolor yellow
            ;print("got one")
            set bin 1
          ]
        ]
      ]
    ]
  ]


  [ ;;; -------------------------------------------- If they are NOT more numerous
    ask n-of ( bin_pop / 3 ) perim_patches [
      set bin 1
      set pcolor yellow
    ]

    let binned count perim_patches with [bin = 1 ]
    let n_to_bin bin_pop - binned
    while [ n_to_bin > 0 ] [
      set binned count perim_patches with [ bin = 1 ]
      set n_to_bin bin_pop - binned
      let binnable_perim perim_patches with [ bin = 1 and any? neighbors with [ human = 1 and bin = 0 ] ]
      let binnable_count count binnable_perim
      let sub_n_to_bin n_to_bin / 2

      if n_to_bin < 50 [
        set sub_n_to_bin 10
      ]
      if n_to_bin < 10 [
        set sub_n_to_bin 1
      ]
      if sub_n_to_bin > binnable_count [
        set sub_n_to_bin binnable_count
      ]

      if print-to-console? [
        print (word "Binnable Perim count: " binnable_count )
        print (word "still must bin: " n_to_bin )
        print (word "There are " binnable_count " patches that I could bin")
      ]

      if binnable_count = 0 [
        set n_to_bin 0
      ]

      ask ( n-of sub_n_to_bin binnable_perim ) [
        let perim_neighbors neighbors with [ member? self perim_patches ]
        let target one-of perim_neighbors with [ human = 1 ]
        if target != nobody [
          ask target [
            set bin 1
            set pcolor yellow
          ]
        ]
      ]
    ]
  ]
end


to setup-overlap-bin-perim-fraction-taught
  let assessable_agentset perim_patches
  let assessable_count count assessable_agentset
  let bins_in_assessment assessable_agentset with [ bin = 1 ]
  let bins_in_assessed_count count bins_in_assessment

  while [ bins_in_assessed_count < taught_pop ] [
    if print-to-console? [
      print (word "assessable agents with bin = 1: " bins_in_assessed_count )
    ]
    set assessable_count count assessable_agentset with [ any? neighbors with [ human = 1 and not member? self assessable_agentset ] ]
    let to_assess taught_pop - assessable_count
    if to_assess > assessable_count [
      set to_assess assessable_count
    ]
    ask n-of to_assess assessable_agentset [
      set assessable_agentset ( patch-set (assessable_agentset ) ( one-of neighbors with [ human = 1 and not member? self assessable_agentset ] ) )
    ]
  ]

  ask assessable_agentset [
    set pcolor pink
  ]
end

to setup-reassess-available-patches

  ;;; Perimeter specific for overlap.
  ;;; Only allows appropriate number of patches to be queried in an overlap procedure
  let tempvar 5000
  let temp_perim_patches patches with [ human = 1 and any? neighbors with [ human = 0 ] ]
  let assessable_agentset temp_perim_patches
  let assessable_count count assessable_agentset
  if print-to-console? [
    print (word "Starting assessable: " assessable_count)
    print (word "Starting trial var: " tempvar )
  ]

  if implement-first = "Teaching" [
    set tempvar bin_pop
  ]
  if implement-first = "Bins" [
    set tempvar taught_pop
  ]

  while [ assessable_count < tempvar ] [
    set assessable_count count assessable_agentset
    if print-to-console? [
      print (word "Assessable count start: " assessable_count )
    ]
    let to_assess tempvar - assessable_count
    if print-to-console? [
      print (word "Temp var: " tempvar)
      print (word "GOING TO ASSESS: " to_assess )
    ]


    ask n-of to_assess assessable_agentset with [ any? neighbors with [ human = 1 and not member? self assessable_agentset ] ] [
      set assessable_agentset ( patch-set (assessable_agentset ) ( one-of neighbors with [ human = 1 and not member? self assessable_agentset ] ) )
    ]

  ]
  if print-to-console? [
    print (word "Assessable count end: " count assessable_agentset )
  ]
  ask assessable_agentset [
    set pcolor pink
  ]
  ask patches with [ human = 1 and not member? self assessable_agentset ] [
    set human 0
  ]
end


;; --------------------------------   End of setup and configurations of different teaching / bin configurations
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////

;; --------------------------------   Setup the selected scenario and all other starting paramaters for a single run
to Initialize
  ct
  cd
  clear-all-plots
  clear-output
  reset-ticks

  setup-initial-constants

  setup-create-human

  setup-create-food

  ask patches[
    ifelse food-nat < food-hum
    [ set food food-hum ]
    [ set food food-nat ]
    if buffer? = true [ set food food-buf ]
    set memory food
  ]
  setup-spawn-bears

  presentation
  setup-scenario-2

  fence-create-sensors
  if fences-on? [
    gis-load-fences
  ]

  if not file-exists? "error_log.csv" [
    file-open "error_log.csv"
    file-print ( word "xcor, " "ycor, " "heading, " "final_dest, " "distance_to_final, " "choosecounter," "cumsum-list," )
    file-close
  ]

  set check_selected_value_list [ ]
  set max_value_list []
end


;; --------------------------------   Initialize all baseline variables for a single run

to setup-initial-constants
  set conflict_bears 0
  set survival_bears 1
  set aversive_bears 0
  set Moves 0
  set HBI+ 0
  set HBI- 0
  set season 0
  set move-list [ ]
  while [length move-list < Move-options * 3] [
    set move-list fput 0 move-list
  ]
  set cumsum-list [ ]
  while [length cumsum-list < Move-options ] [
    set cumsum-list fput 0 cumsum-list
  ]
  set MoveLength-list [ ]
  set short_step_list []
  set long_step_list []
  set short_angle_list []
  set long_angle_list []
  set TurnAngles-list [ ]
  set Pxcords-list [ ]
  set Pycords-list [ ]
  set track_output_list (list ( list "tick" "x" "y") )

  set aveMoveLength 0
  set Totaldistance 0
  set totaltime-outside 0
  set sensors_ok? false
  set init_start_time current_time
  set end_in_urban_count 0
  ask patches [
    set usage_count 0
    set used_this_pathfind? false
  ]


end


;; --------------------------------   Create a new bear with baseline starting variables

to setup-spawn-bears
  create-bears 1  [
    set death 0
    set shape "bear" ; sets the turtle Icon to a bear picture we created
    set color scale-color brown (death * 10) 0 100
    if spawning-type = "random" [
      move-to one-of patches with [ food-nat > 0 ]
    ]
    if spawning-type = "drift-test" [
      move-to one-of patches with [ (food-nat > 0) and ((pxcor + abs(pycor)) > 1000) ]
    ]
    if spawning-type = "in-town" [
      move-to patch 523 300
    ]
    ;setxy random-xcor random-ycor ; randomly places the turtle
    set size 4 ; increases the size of the Bear to 2
    set outside? false
    set deterred 0
    set det-rad 5 ; the initial deterant radius is 5 (arbitrary number)
    set HBI 0
    set food-nat-consumed 0
    set FC 0
    set free 0
    set MoveLength 0
    set TurnAngle 0
    set fleeing? false
    if pen-down? [
      pen-down ; allows the bears path around the landscape to be traced
    ]
  ]
end


;; --------------------------------   Change the current display mode to that selected in the interface

to presentation
  ask patches [
    set pcolor white
    if view = "Food" [
      if food > 0 [
        ifelse BHT1 != 7
        [ set pcolor scale-color green food-nat 0 10 ]
        [ set pcolor scale-color red food-hum 0 10 ]
      ]
      if BHT1 = 9 [ set pcolor cyan ]

      ;if BLD = 1 [ set pcolor yellow]
    ]
    if view = "Food-Nat" [
      if food-nat > 0 [
        set pcolor scale-color green food-nat 0 10
      ]
      if BHT1 = 9 [ set pcolor cyan ]
      if BLD = 1 [ set pcolor yellow]
    ]
    if view = "Food-Hum" [
      if food-hum > 0 [
        set pcolor scale-color red food-hum 0 10
      ]
      if BHT1 = 9 [ set pcolor cyan ]
      ;if BLD = 1 [ set pcolor yellow ]
    ]
    if view = "DTU" [
      if BHT1 > 0 [
        set pcolor scale-color Blue DTU 10000 100
        if BHT1 = 7 [ set pcolor red ]
        if BLD = 1 [ set pcolor yellow ]
      ]
    ]
    if view = "BHT1" [
      if BHT1 > 0 [
        set pcolor (( BHT1 * 5 ) - 3 )
        ;if BHT1 = 7 [ set pcolor red ]
        if BLD = 1 [ set pcolor yellow ]
      ]
    ]
    if view = "BHT2" [
      if BHT2 > 0 [
        set pcolor (( BHT2 * 5 ) - 3 )
        if BLD = 1 [ set pcolor yellow ]
      ]
      if BHT2 = 3 [ set pcolor white ]
    ]
    if view = "BHT3" [
      if BHT3 > 0 [
        set pcolor (( BHT3 * 5 ) - 3 )
        if BLD = 1 [ set pcolor yellow ]
      ]
      if BHT3 = 1 [ set pcolor white ]
    ]
    if view = "Zones" [
      if zone > 0 [
        set pcolor zone
      ]
    ]
  ]

  if view = "Imagery" [
    print("Making imagery background")
    bmp-import
    print("Imported imagery")
    ask patches with [ human = 1 and bin = 0 and educated = 0 ] [
      set pcolor red
    ]
  ]

  ask patches [

    if buffer? = true [ set pcolor scale-color orange food-buf 6 0 ]

    if educated = 1 [
      set pcolor blue
    ]
    if bin = 1 [
      set pcolor yellow
    ]
    if ( bin = 1 ) and (educated = 1 ) [
      set pcolor violet
    ]

    set plabel ""

  ]
  if label-scenario? [
    setup-label-scenario
    ask patches with [ pxcor >= 214 and pxcor < 314 and pycor > 45 and pycor < 65 ] [
      set pcolor black
    ]
    ask patch 264 55 [
      set plabel " 1 Kilometer"
    ]
  ]

end


;; --------------------------------   Imports the imagery view
to bmp-import

;  let bmap bitmap:import "images/whisbase.png"
  let bmap bitmap:import "images/whis_base_rev.png"

  bitmap:copy-to-pcolors bmap false
end

;; --------------------------------   If labels are turned on, label the current scenario details in the Northeast quadrant of the view window
to setup-label-scenario

  ( foreach [ 590 565 540 515 490 465 ] (list "Inc. det. layout: " "Attractant rem. layout: " "Inc. det. fraction: " "Attractant rem. fraction: " "Inc. det. / Attractant rem. relation: " "Implement first: " ) ( list Teaching-Layout Bin-Layout teaching-fraction bin-fraction teach-bin-rela implement-first)   [
    [y string var] ->
    ask patch 250 y [
      set plabel-color black
      set plabel ( word string var )
    ]
    ]
  )
end


; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;; --------------------------------   Run procedures
to A-2-Run-Procedures end
  ; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////


  ;; --------------------------------   Overarching `Go` procedure that calls all procedures that occur in a single tick

to go

  if max-steps <= 0 [ user-message "please enter a time duration" ]
  ;while [ ticks < max-steps and glob_deaths < 1  ] [
  if ( ticks < max-steps and deaths < 1 ) [ ; moves for max-steps Tick-listteps then stops - also stops if death occurs
    fence-maintain-sensors
    let toss random-float 1
    ask bears [
      set pxcords-list fput xcor pxcords-list
      set pycords-list fput ycor pycords-list

      ask patches in-radius 50 [
        set recent_use 0
      ]
      go-check
      ;if deterant >= 5 [ go-death ]                       ; checks for the number of deterants to be less than
      ifelse food < 3 [                                    ; Checks for desireable food at current patch
        ifelse human != 1 [                                ; if food is undesireable it will either flee or move based on the human value
          go-move
        ] [                                                ; moves based on probabillity
          ifelse toss <= det_prob [
            go-flee
          ] [                                              ; If toss is less than the deterrence probability, the bear is detered.
            ifelse bin = 1 [
              set memory memory - 1
              go-move
              set HBI HBI + ( 1 / HBI-factor )
              set HBI+ HBI+ + 1
            ] [
              go-move
              set HBI HBI + ( 1 / HBI-factor )
              set HBI+ HBI+ + 1
            ]
          ]
        ]
      ] [
        ifelse human != 1 [                                ; if food is desireable it will either eat or flee based on the human value
          go-eat                                           ; if there isn't a detering human on the patch then the bear eats
        ] [
          ifelse toss <= det_prob  [
            go-flee                                        ; else the bear is detered.
          ] [
            ;This is where bins come into play
            ifelse bin = 1 [
              set memory memory - 1
              go-move
            ] [
              go-eat
              ;set HBI HBI + ( 1 / HBI-factor )
              set HBI+ HBI+ + 1 ]
          ]
        ]
      ]
    ]

    fence-maintain-sensors
    go-outside? ; checks if the bear is outside the study area
    ifelse outside? = false
    [ tick  ]
    [ tick-advance time-outside
      set totaltime-outside totaltime-outside + time-outside
      ask bears [
        set outside? false
        set color violet
        if print-to-console? [
          print("Moving from outside")
        ]
        ifelse length Pxcords-list > 0 [
          setxy first pxcords-list first pycords-list
        ]
        [
          set color yellow
          move-to one-of patches with [ food-nat > 0 ]
        ]
        set color black

      ]
    ]

    go-conservation-officer

    if ticks >= round (max-steps / 2 ) and season = 0 [ go-season ]

    go-data


  ]

  if ticks mod 25 = 0 [
    update-histogram-plots
    if diffuse-memory? [
      ask patches [ set pcolor scale-color red memory 20 0]
    ]
  ]

  if ( ticks >= max-steps or survival_bears = 0 ) [
    ifelse auto-reinitialize? = false [
      if export-track?[
        gis-export-track
      ]
      stop
    ]
    [
      initialize
    ]
  ]

end


;; --------------------------------   Update the histograms that describe the step lengths and turn angles

to update-histogram-plots
  set-current-plot "Short step turn histogram"
  set-plot-x-range -180 180
  set-histogram-num-bars 30
  histogram short_angle_list

  set-current-plot "Long step turn histogram"
  set-plot-x-range -180 180
  set-histogram-num-bars 30
  histogram long_angle_list

  set-current-plot "Short step histogram"
  set-plot-x-range 0 90
  set-histogram-num-bars 40
  histogram short_step_list

  set-current-plot "Long step histogram"
  set-plot-x-range 90 5000
  set-histogram-num-bars 40
  histogram long_step_list
end


;; --------------------------------   Check the bear characteristics to see if the bear qualifies as a conflict or graduated bear

to go-check
  if HBI < -4.9 [
    set HBI -4.9
  ]
  ifelse HBI <= 0[
    let y ( (- HBI-FCmax / HBI-Habmax ) * HBI + HBI-FCmax )
    if FC >= y [ check-death ]
    if FC <= HBI-Gradmax and HBI <= HBI-Detmax [ check-grad ]
  ]
  [
    ifelse hbi > HBI-habmax or fc > HBI-fcmax [ check-death ]
    [
      let y1 sqrt( (HBI-Habmax) ^ 2 * (1 - ((fc ^ 2) /( hbi-fcmax )^ 2 )))
      let y2 sqrt( ( hbi-fcmax ) ^ 2 * (1 - ((HBI ^ 2) /( HBI-Habmax)^ 2 )))
      if fc > y2 or HBI > y1 [ check-death ]
    ]
  ]
end


;; --------------------------------   Have patches where a bear has been sighted temporarily increase their probability of deterrence

to go-conservation-officer

  if conservation-officer? [
    ; If any patches have been alerted
    if any? patches with [ bear_seen_count > 0 ] [
      ; Ask alerted patches
      ask patches with [ bear_seen_count > 0 ] [
        set bear_seen_count bear_seen_count - 1
        if bear_seen_count <= conservation_officer_persistence [
;          set det_prob std_det_prob * conservation_factor * educated * teach_factor
          set det_prob std_det_prob * conservation_factor
          set pcolor bear_seen_count
        ]
        if bear_seen_count = 0 [
          set det_prob std_det_prob
;          set det_prob std_det_prob
          color-tidy
        ]
      ]
    ]
    ask bears [
      if [bht1] of patch-here = 7 [
        ask patches in-radius 2.5 with [ human = 1 ] [
          ifelse bear_seen_count = 0 [
            set bear_seen_count conservation_officer_persistence + 1 + conservation_officer_delay
          ]
          [
            if bear_seen_count < conservation_officer_persistence [
              set bear_seen_count conservation_officer_persistence
            ]
          ]
        ]
      ]
    ]
  ]

end


to color-tidy ; patch proc
  set pcolor scale-color red food-hum 0 10
  ifelse bin = 1 [
    ifelse educated = 1 [
      set pcolor violet
    ] [
      set pcolor yellow
    ]
  ] [
    if educated = 1 [
      set pcolor blue
    ]
  ]

end


;; --------------------------------   If a bear qualifies as a conflict bear, update relevant statistic variables

to check-death
  update-histogram-plots
  set death death + 1 ;increases the death counter
  set conflict_bears conflict_bears + 1
  set survival_bears survival_bears - 1
  pen-up
  set color scale-color brown ( death * 10 ) 0 100 ;scales the bears colour
                                                   ;set food-hum-taste 0
  set hbi_final HBI
  set fc_final FC
  set det-rad 5
  if pen-down? [
    pen-down
  ]
end


;; --------------------------------   If a bear qualifies as a graduated bear, update relevant statistic variables

to check-grad
  set free free + 1
  set aversive_bears aversive_bears + 1
  set survival_bears survival_bears - 1
end


;; --------------------------------   Create "pseudosteps" for the bear to evaluate, then face the patch at the end of the chosen step.
;  ----------------------------------------------------------------------------------   Attempt to move to that step (using "bear-pathfind")

to go-move
  let x 0

  repeat (length move-list) / 3 [
    ifelse (Sum[food-nat + food-hum] of patches in-radius sqrt(2)) >= ( Prox-rating) [
      set angle move-turn-short
      set dist move-step-short
    ] [
      set angle move-turn-long
      set dist move-step-long
    ]
    if  patch-right-and-ahead angle dist != nobody [
      ifelse ([food + memory] of (patch-right-and-ahead angle dist)) != 0 [
        set move-list replace-item x move-list ([food + memory] of patch-right-and-ahead angle dist)
        set cumsum-list replace-item (x / 3) cumsum-list ([food + memory] of patch-right-and-ahead angle dist)
        set move-list replace-item (x + 1) move-list angle
        set move-list replace-item (x + 2) move-list dist
        set x x + 3
      ] [
        set move-list replace-item x move-list 0
        set cumsum-list replace-item (x / 3) cumsum-list 0
        set move-list replace-item (x + 1) move-list 0
        set move-list replace-item (x + 2) move-list 0
        set x x + 3
      ]
    ]
  ]


  let temp 0
  set index1 0 ; index counter used for the summation loop
  set index2 0 ; index counter used for the position in origonal list of the desired foodmem

  repeat (length cumsum-list  )[ ; makes a list of cumulative sums
    set temp ( temp + item index1 move-list )
    set cumsum-list replace-item (index1 / 3) cumsum-list temp
    set index1 index1 + 3
  ]

  let toss random max cumsum-list

  repeat (length move-list) / 3 [
    if item (index2 / 3) cumsum-list < toss [
      set index2 index2 + 3; picks the bin in the list where the toss lands
    ]
  ]

  set movelength item  (index2 + 2) move-list
  let hold_movelength movelength
  set TurnAngle item (index2 + 1) move-list
  rt (Turnangle)

  bear-pathfind

  gis-bear-spawn-vertex

  set moves moves + 1
  ;  ]
  set last-position patch-right-and-ahead item (index2 + 1) move-list item (index2 + 2 ) move-list
  set movelength hold_movelength
end


to go-move-validate

  ; This is a truncated movement used for validation that does not "pathfind"- the bear just moves to
  ; the new selected patch

  let x 0

  repeat (length move-list) / 3 [
    ifelse (Sum[food-nat + food-hum] of patches in-radius sqrt(2)) >= ( Prox-rating) [
      set angle move-turn-short
      set dist move-step-short
    ] [
      set angle move-turn-long
      set dist move-step-long
    ]
    if  patch-right-and-ahead angle dist != nobody [
      ifelse ([food + memory] of (patch-right-and-ahead angle dist)) != 0 [
        set move-list replace-item x move-list ([food + memory] of patch-right-and-ahead angle dist)
        set cumsum-list replace-item (x / 3) cumsum-list ([food + memory] of patch-right-and-ahead angle dist)
        set move-list replace-item (x + 1) move-list angle
        set move-list replace-item (x + 2) move-list dist
        set x x + 3
      ] [
        set move-list replace-item x move-list 0
        set cumsum-list replace-item (x / 3) cumsum-list 0
        set move-list replace-item (x + 1) move-list 0
        set move-list replace-item (x + 2) move-list 0
        set x x + 3
      ]
    ]
  ]

  let temp 0
  set index1 0 ; index counter used for the summation loop
  set index2 0 ; index counter used for the position in origonal list of the desired foodmem

  repeat (length cumsum-list  )[ ; makes a list of cumulative sums
    set temp ( temp + item index1 move-list )
    set cumsum-list replace-item (index1 / 3) cumsum-list temp
    set index1 index1 + 3
  ]

  let toss random max cumsum-list

  repeat (length move-list) / 3 [
    if item (index2 / 3) cumsum-list < toss [
      set index2 index2 + 3; picks the bin in the list where the toss lands
    ]
  ]

  set movelength item  (index2 + 2) move-list
  set TurnAngle item (index2 + 1) move-list
  rt (Turnangle)
  let value_selected ([food + memory] of patch-ahead movelength )
  let possible reverse sort map [ i -> item i move-list ] ( range 0 60 3 )
  set check_selected_value_list lput ( sentence value_selected possible ) check_selected_value_list

  fd movelength

  set moves moves + 1

  set last-position patch-right-and-ahead item (index2 + 1) move-list item (index2 + 2 ) move-list
end

to memory-increase
  let rad 15
  let inc_amt 0.5
  let max_memory 15

  ask patches in-radius rad with [ bht1 > 0 ] [
    set memory memory + ( inc_amt * (  1 - ( distance myself / ( rad + 0.1 ) ) ) )
    if memory > max_memory [
      set memory max_memory
    ]
  ]
end

;; --------------------------------   Attempt to move to the final destination patch by way of highest-value intermediate patches
to bear-pathfind

  set color pink

  ;;; Draw a line directly to the final destination
  forward movelength
  set dtx xcor
  set dty ycor
  back movelength

  ;;; Store the current heading for later use
  let true_heading heading

  ;;; Clear the recent_use marker off of nearby patches
  ask patches in-radius 100 [
    set recent_use 0
  ]

  ;;; While the distance to the final xy coordinates is greater than 0:
  while [ distancexy dtx dty > 2 ] [
    ;; Face the final destination and set the current patch to having been recently used
    facexy dtx dty
    ask patch-here [
      set recent_use 1
    ]

    ;;; Choose a current target that has not recently been walked on by the bear based on food quality
    let choosecounter 0
    set current_target max-one-of (patches in-cone 2 180 with [recent_use = 0 ]) [food]

    ;;; If the current_target is a patch, face it. Set the movelength to the distance to the current_target,
    ;;;; and do "fence-bear-walks-path" to get to the patch.
    ifelse current_target != nobody [
      face current_target

      ;;; There is an error in Netlogo when numbers get too small or large- this corrects a thrown error with that issue
      if distance current_target < 0.000001 [
        print ("Correcting too-close error.")
        bk 0.0001
      ]
      face current_target
      set movelength distance current_target
      fence-bear-walks-path
    ]
    ;;; If the current target is nobody, try again to choose a real patch, up to 25 times.
    [
      print "Targeted nobody. Trying to get a real target patch..."
      while [ current_target = nobody and choosecounter < 25 ] [
        set current_target max-one-of (patches in-cone 2 100 with [recent_use = 0 ]) [food]
        if choosecounter > 15 [
          ask patches in-radius 10 [
            set recent_use 0
          ]
        ]
        set choosecounter choosecounter + 1
      ]
      if choosecounter >= 25 and current_target = nobody [
        print ("Got stuck, taking a short step directly forward to correct.")

        ;; -------------------------------------------------------------------------------------------------/// error reporting
        print (word " x: " xcor " y: " ycor " target: " current_target " distance to end: " distancexy  dtx dty " choosecounter: " choosecounter )
        file-open "error_log.csv"
        file-print ( word xcor ", " ycor ", " heading ", " (patch dtx dty) ", " (distancexy dtx dty ) ", " choosecounter ", "  (length cumsum-list))
        file-close
        ;; -------------------------------------------------------------------------------------------------/// end error reporting

        facexy dtx dty
        set movelength 1
        fence-bear-walks-path
        set choosecounter 0
      ]
    ]
  ]
  facexy dtx dty
  ;;; There is an error in Netlogo when numbers get too small or large- this corrects a thrown error with that issue
  if distancexy dtx dty < 0.00000001 [
    bk 0.0000001
  ]
  set movelength distancexy dtx dty
  fence-bear-walks-path
end


;; --------------------------------   Attempt to move to the target patch, while checking for fence barriers en-route

to fence-bear-walks-path
  let full-distance movelength
  let col white
  ifelse pen-down? [
    pd
  ]
  [
    pu
  ]

  set color black
  set int-step-len 0.45

  if fleeing? [
    set col 136
  ]

  while [ full-distance > 0 ] [   ;--------------------------------------------- while start

    ifelse fences-on?
    [                                        ;; if fences on

      if ( gis_fences != nobody ) and ( gis:intersects? gis_fences my-links ) [
        ;print ("hit fence")
        set full-distance 0
        set movelength 0
        set dtx xcor
        set dty ycor
      ]

      if full-distance < int-step-len [
        set int-step-len full-distance
      ]

      fd int-step-len


      set full-distance full-distance - int-step-len
    ]

    [       ;; if fences off

      set int-step-len 0.45

      if full-distance < int-step-len [
        set int-step-len full-distance
      ]
      fd int-step-len

      set full-distance full-distance - int-step-len
      if fleeing? = false [   ;;; only check fleeing if bear is not already fleeing
        if [human] of patch-here = 1 [
          let toss random-float 1
          let threshold base_det_prob / travel_factor
          ;print (word "Chance toss: " toss ". Is it lower than the threshold " threshold "?")
          if toss <= threshold [
            if print-to-console? [
              print("I have been intercepted en route!")
            ]
            set full-distance 0
            go-flee
          ]
        ]
      ]
    ]
  ]

  if full-distance = 0 [
    set movelength 0
  ]

  ;                     ======================================================== while end
end


;; --------------------------------   Create a sense agent a short distance ahead of the bear that can check for
;  ----------------------------------------------------------------------------------   intersection between a joining link and the fence shapefile, if loaded

to fence-create-sensors

  ask senses [die]

  let bearlist []
  let sensex []
  let sensey []

  ;;; Creates a sensor ahead, right-ahead, and left-ahead of the bear
  ask bears [
    let nowx xcor ;; hold original x
    let nowy ycor ;; hold original y
    let nowh heading ;; hold original heading
    fd 0.5
    set bearlist lput self bearlist
    set sensex lput xcor sensex
    set sensey lput ycor sensey
    setxy nowx nowy

    set heading nowh
  ]

  ( foreach bearlist sensex sensey [
    [ bname xc yc] ->
    create-senses 1 [
      set shape "circle"
      set size 0.15
      set color white
      setxy xc yc
      create-link-from bname [
        set shape "testlink"
        set color white
        tie
        ; hide-link
      ]
    ]
    ]
  )

  set sensors_ok? true
end


;; --------------------------------    Checks that bear sensors have not been shortened by the bear running into the edge of world.
;; --------------------------------    If they have, refreshes the sensor array

to fence-maintain-sensors
  ;;; Checks that bear sensors have not been squished by the bear running into the edge of world.
  ;;; If they have, refreshes the sensor array
  ask bears [
    foreach sort my-links [
      [lx] ->
      let link_length [link-length] of lx
      if link_length != 0.5 [
        set sensors_ok? false
      ]
    ]
  ]

  if sensors_ok? = false [
    fence-create-sensors
  ]

end


;; --------------------------------    Makes the bear draw yellow lines to indicate the step choices made at a particular point

to bear-example-choice
  let n 0
  let pdistlist []
  let panglist []
  while [ n < 20 ] [
    set pdistlist lput ( item (n + 1) move-list ) pdistlist
    set panglist lput ( item (n + 2 ) move-list ) panglist
    set n n + 1
  ]

  ask bears [
    set color yellow
    let tx xcor
    let ty ycor
    let th heading

    ( foreach pdistlist panglist [
      [di an] ->
      rt an
      fd di
      setxy tx ty
      set heading th
      ]
    )
  ]

end


;; --------------------------------    Reduces the food at a patch and records the food used

to go-eat
  if diffuse-memory? [
    memory-increase
  ]
  if food-nat > 1 [
    set food food - 1 ; eats the food reducing the food value at the patch by one
    set food-nat-consumed food-nat-consumed + 1
    ; set eat 1
  ]
  if BHT1 = 7 and food-hum > 2 [
    set food food - 1 ; eats the food reducing the food value at the patch by one
    set FC FC + ( 1 / FC-factor )
    if human = 1 and memory < 5 [ set memory  memory + 1 ] ; if the bear likes the food because it is an attractive human cell then it increases the memory value
                                                           ; set HBI+ HBI+ + 1 Commented out so that there isn't a linear increase in the food and habituation
                                                           ; set HBI HBI + 1
  ]
  set MoveLength "null"
  set Turnangle "null"
end


;; --------------------------------    Use the fence-bear-walks-procedure to flee from an urban area if deterred

to go-flee

  if print-to-console? [
    print ( "moving-to due to 'go-flee' procedure" )
  ]
  set fleeing? true
  set memory memory - 1

  let escape ( min-n-of 20 ( (patches ) with [ BHT1 > 0 and BHT1 != 7 ]) [distance myself] )

  if print-to-console? [
    print escape
  ]

  if escape = nobody [
    set escape patch-at-heading-and-distance (random 360) (25 * det-rad * sqrt(2) )
  ]

  set escape one-of escape

  set movelength distance escape

  if print-to-console? [
    print ( word "Fleeing " ( movelength * 25 ) " meters")
  ]

  face escape

  fence-bear-walks-path

  gis-bear-spawn-vertex

  ;; reset dtx dty so bear doesn't keep trying to do bear-pathfind after fleeing
  set dtx xcor
  set dty ycor


  set fleeing? false

  if det-rad > 1
    [set det-rad det-rad - 1 ]
  set deterred  1
  set HBI- HBI- + 1
  set HBI HBI - ( 1 / HBI-factor )
  set MoveLength "null"
  set Turnangle "null"
  set flee-count flee-count + 1

end


;; --------------------------------    Change the season from pre-berry to berry, and update the landscape food values

to go-season
  set season season + 1
  setup-create-food
  ask patches with [ BHT1 >= 0 ][
    ifelse food-nat < food-hum
      [ set food food-hum ]
    [ set food food-nat ]
    set memory food
  ]
  presentation
end


;; --------------------------------    Records movement and landscape data

to go-data
  ask bears[
    if buffer? = 0 [
      data-movecalcs
      ;print movelength
      set deterred 0
      if [bht1] of patch-here = 7 [
        set end_in_urban_count end_in_urban_count + 1
      ]
    ]
  ]
end


;; --------------------------------    Sorts movement data into short and long step distance and turn angels, as well as into a master collection list

to data-movecalcs
  if movelength != "null" and Turnangle != "null" [
    let movelength_true ( movelength * 25 )
    ifelse movelength_true <= 90 [
      set short_step_list fput movelength_true short_step_list
      set short_angle_list fput Turnangle short_angle_list
    ]
    [
      set long_step_list fput movelength_true long_step_list
      set long_angle_list fput Turnangle long_angle_list
    ]
  ]
  ifelse movelength != "null" and Turnangle != "null" [
    set MoveLength-list fput (movelength * 25 ) MoveLength-list
    set avemovelength (totaldistance / ( length MoveLength-list + 1))
    set avemovelength ( totaldistance / ( length short_step_list + length long_step_list ) )
    set TurnAngles-list fput Turnangle TurnAngles-list
  ]
  [ set MoveLength-list fput movelength MoveLength-list
    set TurnAngles-list fput Turnangle TurnAngles-list ]

end


;; --------------------------------    Set the global constants (called in setup)

to Simulate-Set_Constants
  set HBI-Gradmax 3
  set HBI-FCmax 8
  set HBI-Habmax 5
  set HBI-Detmax -2
  set Prox-rating 20.5
  set Move-options 20
  set Buffer-distance 200
  set max-steps 4800

end



; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;; --------------------------------   Output and export procedures
to A-3-Export-and-Output-Procedures end
  ; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////


  ;; --------------------------------   Validate from real step xy and headings

to gis-validate-fake
  initialize

  let actual_points nobody

  let seas ""

  ifelse seas = "Berry" [
    set season 1
    setup-create-food
    ask patches with [ BHT1 >= 0 ][
      ifelse food-nat < food-hum
      [ set food food-hum ]
      [ set food food-nat ]
      set memory food
    ]
    set actual_points gis:load-dataset "GIS_files/shapefiles/clipped_bear_berry.shp"
  ] [
    set actual_points gis:load-dataset "GIS_files/shapefiles/clipped_bear_preberry.shp"
  ]

  set track_output_list []

  let feature_list gis:feature-list-of actual_points

  foreach sublist feature_list 1 25 [
    node ->
    let x0 first gis:location-of first first gis:vertex-lists-of node
    let y0 last gis:location-of first first gis:vertex-lists-of node
    let base_heading  gis:property-value node "NT_DG_S"

    ask one-of bears [

      ; Repeat for validation (and in case step exceeds cutoff value)
      repeat 1 [

        ; Move to the coordinates of the current node, change heading to
        ; the heading set by the ltraj trajectory from Adehabitat
        set color yellow
        setxy x0 y0
        set heading base_heading
        ;print ( word "my heading is " heading )
        wait 0.01

        ; Select a new patch and move to it
        go-move-validate

        ; Record the UTM coordinates of the new patch into track_output_list
        let b_env gis:envelope-of bear 0
        let x first b_env
        let y last b_env
        set track_output_list lput ( list x y ) track_output_list
      ]
    ]
  ]


end

to gis-validate-steps

  user-message "This will output a file of new xy coordinates based on real steps and may take a few minutes. Proceed?"
  let reps user-one-of "How many false steps do you want the bear to choose? 3 steps takes roughly 4 minutes." [ 1 3 5 10 20 ]
  let seas user-one-of "What seasonal food values do you want present?" [ "Preberry" "Berry" ]
  let fname user-input "File name (no extension): "

  initialize

  let actual_points nobody

  ifelse seas = "Berry" [
    set season 1
    setup-create-food
    ask patches with [ BHT1 >= 0 ][
      ifelse food-nat < food-hum
      [ set food food-hum ]
      [ set food food-nat ]
      set memory food
    ]
    set actual_points gis:load-dataset "GIS_files/shapefiles/clipped_bear_berry.shp"
  ] [
    set actual_points gis:load-dataset "GIS_files/shapefiles/clipped_bear_preberry.shp"
  ]

  set track_output_list []

  let feature_list gis:feature-list-of actual_points

  foreach feature_list [
    node ->
    let x0 first gis:location-of first first gis:vertex-lists-of node
    let y0 last gis:location-of first first gis:vertex-lists-of node
    let base_heading  gis:property-value node "NT_DG_S"

    ask one-of bears [

      ; Repeat for validation (and in case step exceeds cutoff value)
      repeat reps [

        ; Move to the coordinates of the current node, change heading to
        ; the heading set by the ltraj trajectory from Adehabitat
        set color yellow
        setxy x0 y0
        set heading base_heading

        ; Select a new patch and move to it
        go-move-validate

        ; Record the UTM coordinates of the new patch into track_output_list
        let b_env gis:envelope-of bear 0
        let x first b_env
        let y last b_env
        set track_output_list lput ( list x y ) track_output_list
      ]
    ]
  ]

csv:to-file ( word "gis_files/tracks/" fname ".csv" ) track_output_list

end

;; --------------------------------   Exports a raster of each natural and human foods

to gis-food-raster-out

  ;; Set up preberry food values
  ask patches with [ BHT1 >= 0 ] [
    if PRB1 > 0 and PRB2 > 0 and PRB3 > 0 [
      set food-nat (  ( DEC1 *(6 - PRB1) )  +  ( DEC2 *(6 - PRB2) ) +  ( DEC3 *(6 - PRB3)) )
    ]
    if PRB1 > 0 and PRB2 > 0 and PRB3 <= 0 [
      set food-nat (DEC1 *(6 - PRB1) + DEC2 *(6 - PRB2))/ (DEC1 + DEC2)
    ]
    if PRB1 > 0 and PRB2 <= 0 and PRB3 <= 0 [
      set food-nat (DEC1 *(6 - PRB1)/ DEC1)
    ]
  ]

  ask patches[
    ifelse food-nat < food-hum
    [ set food food-hum ]
    [ set food food-nat ]
    if buffer? = true [ set food food-buf ]
    set memory food
  ]

  ;; Export preberry food values
  gis:store-dataset ( gis:patch-dataset food ) "preberry_food.asc"
  gis:store-dataset ( gis:patch-dataset food-nat ) "preberry_food_nat.asc"

  ;; Set up berry food values
  ask patches with [ BHT1 >= 0 ] [
    if BRY1 > 0 and BRY2 > 0 and BRY3 > 0 [
      set food-nat (DEC1 *(6 - BRY1) + DEC2 *(6 - BRY2) + DEC3 *(6 - BRY3))
    ]
    if BRY1 > 0 and BRY2 > 0 and BRY3 <= 0 [
      set food-nat (DEC1 *(6 - BRY1) + DEC2 *(6 - BRY2)) / (DEC1 + DEC2)
    ]
    if BRY1 > 0 and BRY2 <= 0 and BRY3 <= 0 [
      set food-nat (DEC1 *(6 - BRY1)/ DEC1)
    ]
  ]

  ask patches[
    ifelse food-nat < food-hum
    [ set food food-hum ]
    [ set food food-nat ]
    if buffer? = true [ set food food-buf ]
    set memory food
  ]

  ;; Export preberry food values
  gis:store-dataset ( gis:patch-dataset food ) "berry_food.asc"
  gis:store-dataset ( gis:patch-dataset food-nat ) "berry_food_nat.asc"
end


;; --------------------------------   Exports model bear track vertices
to gis-bear-spawn-vertex

  if export-track? [
;    hatch-vertices 1 [
;      set size 2.5
;    0]
    let b_env gis:envelope-of bear 0
    let x first b_env
    let y last b_env
    set track_output_list lput ( list ticks x y ) track_output_list

  ]
end


to gis-export-track
  csv:to-file ( word "gis_files/tracks/track_" current_datetime  ".csv" ) track_output_list
end

;; --------------------------------   Exports a snapshot of the current view window

to snapshot-out

  let tlay ""
  let blay ""
  let tper teaching-fraction
  let bper bin-fraction
  let tbrela teach-bin-rela
  let ifirst implement-first

  ifelse Teaching-Layout = "None" [
    set tlay "tl_n"
  ]
  [
    if Teaching-Layout = "Cluster" [
      set tlay "tl_clu"
    ]
    if Teaching-Layout = "Perimeter Inclusive" [
      set tlay "tl_pi"
    ]
    if Teaching-Layout = "Perimeter Conservative" [
      set tlay "tl_pc"
    ]
    if Teaching-Layout = "Random" [
      set tlay "tl_r"
    ]
  ]

  ifelse Bin-Layout = "None" [
    set blay "bl_n"
  ]
  [
    if Bin-Layout = "Cluster" [
      set blay "bl_clu"
    ]
    if Bin-Layout = "Perimeter Inclusive" [
      set blay "bl_pi"
    ]
    if Bin-Layout = "Perimeter Conservative" [
      set blay "bl_pc"
    ]
    if Bin-Layout = "Random" [
      set blay "bl_r"
    ]
  ]

  let imgname (word tlay "-" blay "--tper" tper "-bper" bper "--" tbrela "-" ifirst "_first" )

  ;let imgname (word substring date-and-time 0 2 substring date-and-time 3 5 "_" (substring date-and-time 13 15) "_" ( substring date-and-time 16 27 ) "_"  random 10000 )
  export-view (word "c:/Users/lukepc/on_board_bear_files/nlogo_img_outs/" imgname ".png")
end


;; --------------------------------   Opens a viewer window that tracks mouse-down movement for easy visual inspection

to scanner-darkly
  if count arrows < 1 [
    create-arrows 1 [
      hide-turtle
    ]
    inspect one-of arrows
  ]
  ask one-of arrows [
    if mouse-down? [
      setxy mouse-xcor mouse-ycor
    ]
  ]
  stop-inspecting-dead-agents
end


;; --------------------------------   Outputs the current step lists to a collection file for each short and long steps

to steps-lists-out

  let longfile  "Results/long_step_compile.csv"
  let shortfile "Results/short_step_compile.csv"
  let longturnfile "Results/long_turn_compile.csv"
  let shortturnfile "Results/short_turn_compile.csv"


  if length long_step_list > 0[
    file-open longfile
    foreach long_step_list [
      i ->
      file-type i
      file-type ", \n"
    ]
    file-close
  ]

  if length short_step_list > 0 [
    file-open shortfile
    foreach short_step_list [
      i ->
      file-type i
      file-type ", \n"
    ]
    file-close
  ]
  if length long_angle_list > 0[
    file-open longturnfile
    foreach long_angle_list [
      i ->
      file-type i
      file-type ", \n"
    ]
    file-close
  ]

  if length short_angle_list > 0 [
    file-open shortturnfile
    foreach short_angle_list [
      i ->
      file-type i
      file-type ", \n"
    ]
    file-close
  ]

end

; ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
; ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;; --------------------------------  To-Report Reporter Section

to A-4-Reporters-section end

  ; //////////////////////////////////////////////////////////////////////////////////////////////////////////////////

  ;; --------------------------------   Returns a long step from a distribution
  ;; --------------------------------   Formula derived from best-fit line of quartiles plot of long step lengths. Analysis completed in R

to-report move-step-long

  let y -1

  while [ y < 90 or y > 5000 ] [
    let x random-float 1
    set y ( exp ( 4.486842997 * x ^ 0 + 3.554821993 * x ^ 1 + 23.79092307 * x ^ 2 + -259.5209848 * x ^ 3 + 1146.737198 * x ^ 4 + -2667.282214 * x ^ 5 + 3409.728626 * x ^ 6 + -2264.20863 * x ^ 7 + 611.1803312 * x ^ 8 ) )
  ]
  report ( y / 25 )

end


;; --------------------------------   Returns a short step from a distribution
;; --------------------------------   Formula derived from best-fit line of quartiles plot of short step lengths. Analysis completed in R

to-report move-step-short

  let y -1

  while [ y < 0 or y > 90 ] [
    let x random-float 1
    set y  0.4015916508 * x ^ 0 + 99.91733503 * x ^ 1 + -954.8520998 * x ^ 2 + 6142.767118 * x ^ 3 + -21733.07518 * x ^ 4 + 44339.88899 * x ^ 5 + -51753.15005 * x ^ 6 + 32138.54168 * x ^ 7 + -8190.227144 * x ^ 8
  ]
  report ( y / 25 )

end


;; --------------------------------   Returns a long step turn from a distribution
;; --------------------------------   Formula derived from best-fit line of quartiles plot of long step turns. Analysis completed in R

to-report move-turn-long

  let y -200

  while [ y < -180 or y > 180 ] [
    let x random-float 1
    set y (-182.6663687 * x ^ 0 + 259.5392199 * x ^ 1 + 1809.461381 * x ^ 2 + -6165.288537 * x ^ 3 + 7401.307452 * x ^ 4 + -2942.471318 * x ^ 5)
  ]
  report(y)

end


;; --------------------------------   Returns a short step turn from a distribution
;; --------------------------------   Formula derived from best-fit line of quartiles plot of short step turns. Analysis completed in R

to-report move-turn-short

  let y -200
  while [  y < -180  or  y > 180  ] [
    let x random-float 1
    set y ( -182.941636 * x ^ 0 + 371.5443761 * x ^ 1 + -2499.64374 * x ^ 2 + 16828.88733 * x ^ 3 + -47629.76264 * x ^ 4 + 69176.28784 * x ^ 5 + -50248.59992 * x ^ 6 + 14365.31852 * x ^ 7 )
  ]
  report y

end


;; --------------------------------   If the bear moves outside, records time spent outside

to go-outside?
  ask bears [
    if buffer? = true [
      set outside? true
      set time-outside round ( outside?-dist (random-float 1) )
    ]
  ]
end


;; --------------------------------   Reports a distribution of time outside for "go-outside"

to-report outside?-dist [P]
  let n 0
  while [ n < 124 ][
    if outside?dist-F(n) <= P and P < outside?dist-F(n + 0.5) [ report n + 0.5]
    set n n + 0.5
  ]
  if n = 124 [ report n ]
end


;; --------------------------------   Reports a distribution of time outside for "outside?dist-F [ n ]"

to-report outside?dist-F [ n ]
  report ( 1 - exp(-0.113 * n ))
end

;;; -------------------------- Reporters to simplify Behavior Space experiments

;; --------------------------------   Reports a file-name-friendly datetime stamp

to-report current_datetime
  report ( word (substring date-and-time 0 2) "-" (substring date-and-time 3 5) "-" (substring date-and-time 6 8 ) "-" (substring date-and-time 13 15) "_" ( substring date-and-time 16 27 ) )
end

;; --------------------------------   Reports the xcor of the current patch in use

to-report round-x
  if ticks > 0 [
    report ( [([pxcor] of patch-here)] of bear 0 )  ;;
  ]
end

;; --------------------------------   Reports the ycor of the current patch in use

to-report round-y
  if ticks > 0 [
    report ( [([pycor] of patch-here)] of bear 0 )
  ]
end

;; --------------------------------   Count of the deaths of the bear

to-report deaths
  report [death] of bear 0
end

;; --------------------------------   HBI of the bear

to-report HBI-bear
  report [HBI] of bear 0
end

;; --------------------------------   FC of the bear

to-report FC-bear
  report [FC] of bear 0
end

;; --------------------------------   Current time (from the system) in a string format

to-report current_time
  ; report ( word (substring date-and-time 0 2) (substring date-and-time 3 5) (substring date-and-time 13 15) "_" ( substring date-and-time 16 27 ) )
  report ( word (substring date-and-time 0 8) (substring date-and-time 12 15) " " ( substring date-and-time 16 27 ) )
end

;; --------------------------------   Reports the mean of the long_step_list, or zero if it's empty

to-report long-step-clean
  let out 0
  if length long_step_list > 0 [
    set out mean long_step_list
  ]
  report out
end

;; --------------------------------   Reports the mean of the long_step_list, or zero if it's empty

to-report short-step-clean
  let out 0
  if length short_step_list > 0 [
    set out mean short_step_list
  ]
  report out
end
@#$#@#$#@
GRAPHICS-WINDOW
180
10
1031
686
-1
-1
1.0
1
10
1
1
1
0
0
0
1
0
842
0
666
1
1
1
ticks
60.0

BUTTON
0
10
175
43
Load GIS
Startup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
0
76
175
109
NIL
Go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
0
43
175
76
NIL
Initialize
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1410
10
1810
240
HBI vs FC
Human Bear Interactions
Food Conditioning
-5.0
6.0
-1.0
17.0
false
false
"plot-pen-up\nlet a -7\nset-plot-pen-color red\nset-plot-pen-mode 0\nplot-pen-down\nrepeat 11[\nwhile [ a < 5 ] [\nifelse a > 0\n[plotxy a sqrt( abs(( hbi-fcmax ) ^ 2 * (1 - ((a ^ 2) /( HBI-Habmax)^ 2 ))))]\n[plotxy a ( (- HBI-FCmax / HBI-Habmax ) * a + HBI-FCmax ) ]\nset a a + 0.05\n]\n]\n\n\n; Draw the gradbox\nplot-pen-up\nplotxy -5 HBI-Gradmax\nset-plot-pen-color 89\nplot-pen-down\nlet x -5 \nwhile [ x < HBI-detmax ] [\nplotxy x 0\nset x x + 0.01\nplotxy x HBI-gradmax\n]\nplot-pen-up\n\nplotxy HBI-detmax 0\nplot-pen-down\nset-plot-pen-color sky - 1\nplotxy HBI-Detmax HBI-Gradmax\nplotxy -5 HBI-Gradmax\n\n\n; Draw the grid\nplot-pen-up\nset-plot-pen-color green - 1\nplotxy -7 0\nplot-pen-down\nplotxy 7 0\nplot-pen-up\nplotxy 0 0\nplot-pen-down\nplotxy 0 20\nplot-pen-up\n\n\n\n\n\n\n; Reset the pen to zero for bear-tracking\nplot-pen-up\nplotxy 0 0\nset-plot-pen-color black\nplot-pen-down" ""
PENS
"pen-1" 1.0 0 -16777216 true "" "ask bears [ plotxy HBI FC ]"

PLOT
1610
240
1810
390
Long step histogram
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

MONITOR
1410
390
1610
435
Average short step length [m]
;Avemovelength * 25\nmean short_step_list
2
1
11

PLOT
1410
435
1610
585
Short step turn histogram
NIL
NIL
-180.0
180.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

SWITCH
0
140
175
173
HighestValue
HighestValue
0
1
-1000

CHOOSER
0
173
175
218
view
view
"BHT1" "BHT2" "BHT3" "DTU" "Food-Nat" "Food-Hum" "Food" "Zones" "Imagery"
6

BUTTON
0
218
175
251
Change View
presentation
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
0
250
175
283
HBI-factor
HBI-factor
1
100
12.0
1
1
NIL
HORIZONTAL

SLIDER
0
280
175
313
FC-Factor
FC-Factor
1
100
12.0
1
1
NIL
HORIZONTAL

CHOOSER
0
313
175
358
Teaching-Type
Teaching-Type
"IncDet" "DecFood-Urb" "Both" "none"
0

CHOOSER
0
357
175
402
Teaching-Layout
Teaching-Layout
"Random" "Perimeter Conservative" "Perimeter Inclusive" "Cluster" "None"
3

CHOOSER
0
400
175
445
Bin-Layout
Bin-Layout
"Random" "Perimeter Inclusive" "Perimeter Conservative" "Cluster" "None"
2

SLIDER
0
444
175
477
teaching-fraction
teaching-fraction
0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
0
477
175
510
bin-fraction
bin-fraction
0
1
0.5
0.01
1
NIL
HORIZONTAL

CHOOSER
0
509
175
554
Urban-Food
Urban-Food
"Random" "Zones"
1

MONITOR
1410
640
1610
685
Attractant management layout
Bin-Layout
17
1
11

MONITOR
1610
640
1810
685
Cells with attractant management
(word ( bin-fraction * 100 ) \" %\")
17
1
11

MONITOR
1610
740
1810
785
Increased deterrence type
Teaching-Type
17
1
11

MONITOR
1410
695
1810
740
Increased deterrence layout
Teaching-Layout
17
1
11

MONITOR
1410
740
1610
785
Cells with increased deterrence
(word ( teaching-fraction * 100 ) \" %\")
17
1
11

CHOOSER
0
554
175
599
teach-bin-rela
teach-bin-rela
"Random" "Overlap" "Opposite"
0

MONITOR
1610
785
1810
830
Times deterred
flee-count
0
1
11

CHOOSER
0
849
175
894
spawning-type
spawning-type
"random" "drift-test" "in-town"
0

SWITCH
0
686
175
719
fences-on?
fences-on?
1
1
-1000

SWITCH
0
719
175
752
print-to-console?
print-to-console?
1
1
-1000

BUTTON
1610
885
1810
918
Scanner window
scanner-darkly
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
0
599
175
644
implement-first
implement-first
"Teaching" "Bins"
1

CHOOSER
0
642
175
687
fence-config
fence-config
"buff_1000_r_150_l_150.shp" "buff_300_r_150_l_150.shp" "buff_500_r_150_l_150.shp" "convex_500_few.shp" "drift.shp" "new_urban_utm.shp" "paths_r_1000_l_100.shp" "paths_r_1000_l_300.shp" "paths_r_1000_l_500.shp" "paths_r_100_l_100.shp" "paths_r_100_l_300.shp" "paths_r_250_l_300.shp" "paths_r_250_l_500.shp" "urban_buffer_25.shp" "urban_buffer_50.shp" "urban_convex.shp" "urban_strict.shp" "No fence"
17

SWITCH
0
752
175
785
pen-down?
pen-down?
0
1
-1000

INPUTBOX
0
893
175
953
base_det_prob
0.01
1
0
Number

MONITOR
1410
785
1610
830
Base deterrence probability
base_det_prob
17
1
11

INPUTBOX
0
1013
175
1073
travel_factor
10.0
1
0
Number

INPUTBOX
0
953
175
1013
teach_factor
10.0
1
0
Number

MONITOR
1410
830
1610
875
Taught deterrence probability
base_det_prob * teach_factor
17
1
11

SWITCH
0
109
175
142
auto-reinitialize?
auto-reinitialize?
1
1
-1000

SWITCH
0
784
175
817
conservation-officer?
conservation-officer?
1
1
-1000

INPUTBOX
0
1073
175
1133
conservation_factor
2.0
1
0
Number

SWITCH
1410
917
1610
950
label-scenario?
label-scenario?
1
1
-1000

BUTTON
1610
915
1810
949
NIL
update-histogram-plots
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1410
240
1610
390
Short step histogram
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

PLOT
1610
435
1810
585
Long step turn histogram
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" ""

MONITOR
1610
390
1810
435
Average long step length [m]
mean long_step_list
17
1
11

MONITOR
1410
585
1610
630
Average short turn angle (degrees)
mean short_angle_list
2
1
11

MONITOR
1610
585
1810
630
Average long turn angle (degrees)
mean long_angle_list
17
1
11

CHOOSER
0
1133
175
1178
vegetation-modification
vegetation-modification
"None" "100m buffer reduction" "200m buffer reduction" "3 diversionary points" "400m-600m buffer increase" "Poor berry crop" "Superior berry crop"
0

BUTTON
1410
885
1610
918
Reset variables to base
set-variable-base-values
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1610
830
1810
875
Travelling deterrence probability
base_det_prob / travel_factor
17
1
11

SWITCH
0
816
175
849
diffuse-memory?
diffuse-memory?
1
1
-1000

SWITCH
180
990
307
1023
export-track?
export-track?
1
1
-1000

BUTTON
430
1015
567
1048
NIL
gis-food-raster-out
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
420
1105
592
1138
Generate validation steps
gis-validate-steps\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
620
1040
1342
1085
natural w/ food value > 3
( count patches with [ BHT1 != -9999 and BHT1 != 7 and food >= 3 ] ) / ( count patches with [ BHT1 != -9999 and BHT1 != 7 ] )
17
1
11

MONITOR
625
1110
777
1155
human w/ food value > 3
( count patches with [ BHT1 != -9999 and BHT1 = 7 and food >= 3 ] ) / ( count patches with [ BHT1 != -9999 and BHT1 = 7 ] )
17
1
11

SLIDER
190
1070
387
1103
conservation_officer_delay
conservation_officer_delay
0
5
4.0
1
1
NIL
HORIZONTAL

SLIDER
190
1120
422
1153
conservation_officer_persistence
conservation_officer_persistence
1
5
4.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bear
true
0
Circle -16777216 true false 118 148 120
Polygon -16777216 true false 240 210 225 120 150 120 120 195 120 210 240 210
Polygon -16777216 true false 225 120 178 65 150 105 150 120
Circle -16777216 true false 137 62 42
Circle -16777216 true false 164 54 18
Polygon -16777216 true false 157 63 156 60 158 45 166 49 170 63
Polygon -6459832 true false 152 64 120 60 120 75 150 105
Polygon -16777216 true false 150 120 120 90 112 103 135 150 150 150
Polygon -16777216 true false 150 135 91 160 90 176 117 173 136 170
Circle -16777216 true false 99 82 21
Rectangle -16777216 true false 77 148 91 176
Polygon -16777216 true false 157 264 120 255 93 251 77 230 90 221 102 237 119 224 76 209 76 187 90 187 90 197 125 196
Polygon -7500403 true true 234 179 227 130 148 129 127 180
Circle -7500403 true true 160 72 8
Circle -16777216 true false 158 72 6

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

default-2
true
0
Polygon -16777216 true false 150 5 40 250 150 205 260 250
Polygon -7500403 true true 150 30 75 210 150 205 225 210

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

line-indicator
true
0
Rectangle -7500403 true true -60 0 300 15

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Jared-1-bin-perim-limited-fence-updated" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Perimeter Conservative&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;paths_r_1000_l_300.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Jared-2-high-det-high-fence-updated" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;buff_500_r_150_l_150.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base" repetitions="1" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print(word "Behaviour space experiment run " behaviorspace-run-number " complete")
print(current_time)</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="all_fence_run-base" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
      <value value="&quot;buff_1000_r_150_l_150.shp&quot;"/>
      <value value="&quot;buff_300_r_150_l_150.shp&quot;"/>
      <value value="&quot;buff_500_r_150_l_150.shp&quot;"/>
      <value value="&quot;urban_buffer_25.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_100.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_300.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_500.shp&quot;"/>
      <value value="&quot;paths_r_100_l_100.shp&quot;"/>
      <value value="&quot;paths_r_100_l_300.shp&quot;"/>
      <value value="&quot;paths_r_250_l_300.shp&quot;"/>
      <value value="&quot;paths_r_250_l_500.shp&quot;"/>
      <value value="&quot;urban_buffer_50.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="t-lay-t-fra-base" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;Cluster&quot;"/>
      <value value="&quot;Perimeter Conservative&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="b-lay-b-fra-base" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;Cluster&quot;"/>
      <value value="&quot;Perimeter Conservative&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="veg-modifications-base" repetitions="1" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
      <value value="&quot;100m buffer reduction&quot;"/>
      <value value="&quot;200m buffer reduction&quot;"/>
      <value value="&quot;3 diversionary points&quot;"/>
      <value value="&quot;400m-600m buffer increase&quot;"/>
      <value value="&quot;Poor berry crop&quot;"/>
      <value value="&quot;Superior berry crop&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conservation-officer-base" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="assess_base_det" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")
print(current_time)</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>stop_count</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="track-patch-usage?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="export_tracks" repetitions="500" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print(word "Behaviour space experiment run " behaviorspace-run-number " complete")
print(current_time)
gis-export-track</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export-track?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conservation-officer-2" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="conservation-officer-threshold" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="conservation_officer_delay" first="0" step="1" last="3"/>
    <steppedValueSet variable="conservation_officer_persistence" first="2" step="1" last="4"/>
  </experiment>
  <experiment name="conservation-officer-threshold-2" repetitions="100" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_officer_delay">
      <value value="4"/>
    </enumeratedValueSet>
    <steppedValueSet variable="conservation_officer_persistence" first="2" step="1" last="4"/>
  </experiment>
  <experiment name="all_fence_run-new" repetitions="100" runMetricsEveryStep="false">
    <setup>if gis_loaded? != true 
[ 
startup 
]
initialize</setup>
    <go>go</go>
    <final>print("Behaviour space experiment complete.")</final>
    <timeLimit steps="4800"/>
    <exitCondition>conflict_bears &gt; 0
or
aversive_bears &gt; 0</exitCondition>
    <metric>HBI-bear</metric>
    <metric>FC-bear</metric>
    <metric>conflict_bears</metric>
    <metric>survival_bears</metric>
    <metric>aversive_bears</metric>
    <metric>init_start_time</metric>
    <metric>current_time</metric>
    <metric>end_in_urban_count</metric>
    <enumeratedValueSet variable="auto-reinitialize?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HighestValue">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HBI-factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FC-Factor">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Type">
      <value value="&quot;IncDet&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Teaching-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Bin-Layout">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teaching-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bin-fraction">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Urban-Food">
      <value value="&quot;Zones&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach-bin-rela">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="implement-first">
      <value value="&quot;Bins&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fence-config">
      <value value="&quot;no_fence.shp&quot;"/>
      <value value="&quot;buff_1000_r_150_l_150.shp&quot;"/>
      <value value="&quot;buff_300_r_150_l_150.shp&quot;"/>
      <value value="&quot;buff_500_r_150_l_150.shp&quot;"/>
      <value value="&quot;urban_buffer_25.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_100.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_300.shp&quot;"/>
      <value value="&quot;paths_r_1000_l_500.shp&quot;"/>
      <value value="&quot;paths_r_100_l_100.shp&quot;"/>
      <value value="&quot;paths_r_100_l_300.shp&quot;"/>
      <value value="&quot;paths_r_250_l_300.shp&quot;"/>
      <value value="&quot;paths_r_250_l_500.shp&quot;"/>
      <value value="&quot;urban_buffer_50.shp&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fences-on?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation-officer?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spawning-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base_det_prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="teach_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="travel_factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conservation_factor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vegetation-modification">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

testlink
0.0
-0.2 1 4.0 4.0
0.0 1 1.0 0.0
0.2 1 4.0 4.0
link direction
true
0
Polygon -7500403 true true 105 180 150 150 195 180 105 180
@#$#@#$#@
1
@#$#@#$#@
